@@ -142,7 +142,6 @@
 //! For the user guide and futher documentation, please read
 //! [The shadow-rs document](https://github.com/baoyachi/shadow-rs).
 //!
-pub extern crate const_format;
 
 mod build;
 mod ci;
@@ -169,6 +168,7 @@ use git::*;
 
 use crate::ci::CiType;
 use crate::time::BuildTime;
+pub use const_format::*;
 use std::collections::HashMap;
 use std::env as std_env;
 use std::fs::File;
